@@ -5,6 +5,8 @@ __all__ = [
     "tf_describe",
     "tran_inner",
     "tf_inner",
+    "tran_pca",
+    "tf_pca",
     "tran_sobol",
     "tf_sobol",
 ]
@@ -17,7 +19,7 @@ import re
 import itertools
 import warnings
 
-from grama import pipe, custom_formatwarning
+from grama import add_pipe, pipe, custom_formatwarning
 from toolz import curry
 
 warnings.formatwarning = custom_formatwarning
@@ -26,7 +28,7 @@ warnings.formatwarning = custom_formatwarning
 # --------------------------------------------------
 @curry
 def tran_sobol(df, typename="ind", digits=2, full=False):
-    """Post-process results from gr.eval_hybrid()
+    r"""Post-process results from gr.eval_hybrid()
 
     Estimate Sobol' indices based on hybrid point evaluations (Sobol', 1999).
     Intended as post-processor for gr.eval_hybrid().
@@ -43,6 +45,10 @@ def tran_sobol(df, typename="ind", digits=2, full=False):
     Notes:
         - Index type ["first", "total"] is inferred from input df._meta;
           this is assigned by gr.eval_hybrid().
+        - Index normalization coded in the "ind" column;
+          S: Normalized index
+          T: Un-normalized index
+          var: Total variance
 
     References:
         I.M. Sobol', "Sensitivity Estimates for Nonlinear Mathematical Models"
@@ -148,17 +154,64 @@ def tran_sobol(df, typename="ind", digits=2, full=False):
     return df_res
 
 
-@pipe
-def tf_sobol(*args, **kwargs):
-    return tran_sobol(*args, **kwargs)
-
+tf_sobol = add_pipe(tran_sobol)
 
 ## Linear algebra tools
 ##################################################
+## Principal Component Analysis (PCA)
+@curry
+def tran_pca(df, var=None, lamvar="lam", standardize=False):
+    r"""Principal Component Analysis
+
+    Compute principal directions and eigenvalues for a dataset. Can specify
+    columns to analyze, or just analyze all numerical columns.
+
+    Args:
+        df (DataFrame): Data to analyze
+        var (list of str or None): List of columns to analyze
+        lambvar (str): Name to give eigenvalue column; default="lam"
+        standardize (bool): Standardize columns? default=False
+
+    Returns:
+        DataFrame: principal directions and eigenvalues
+
+    References:
+        TODO
+
+    Examples:
+
+        >>> import grama as gr
+        >>> from grama.data import df_stang
+        >>> df_pca = df_stang >> gr.tf_pca()
+
+    """
+    ## Handle variable selection
+    columns_numeric = list(df.select_dtypes("number").columns)
+    if var is None:
+        var = columns_numeric
+    else:
+        if not set(var).issubset(set(columns_numeric)):
+            raise ValueError("`var` must be a subset of numeric df.columns")
+
+    ## Setup
+    X = df[var].values
+    if standardize:
+        U, s, Vh = svd((X - df[var].mean().values) / df[var].std().values)
+    else:
+        U, s, Vh = svd(X - df[var].mean().values)
+
+    df_tmp = DataFrame(data=Vh, columns=var)
+    df_tmp[lamvar] = s
+
+    return df_tmp[[lamvar] + var]
+
+
+tf_pca = add_pipe(tran_pca)
+
 ## Gradient principal directions (AS)
 @curry
 def tran_asub(df, prefix="D", outvar="out", lamvar="lam"):
-    """Active subspace estimator
+    r"""Active subspace estimator
 
     Compute principal directions and eigenvalues for all outputs based on output
     of ev_grad_fd() to estimate the /active subspace/ (Constantine, 2015).
@@ -208,16 +261,13 @@ def tran_asub(df, prefix="D", outvar="out", lamvar="lam"):
     return concat(list_df).reset_index(drop=True)
 
 
-@pipe
-def tf_asub(*args, **kwargs):
-    return tran_asub(*args, **kwargs)
-
+tf_asub = add_pipe(tran_asub)
 
 # --------------------------------------------------
 ## Inner product
 @curry
 def tran_inner(df, df_weights, prefix="dot", name=None, append=True):
-    """Inner products
+    r"""Inner products
 
     Compute inner product of target df with weights defined by df_weights.
 
@@ -304,28 +354,24 @@ def tran_inner(df, df_weights, prefix="dot", name=None, append=True):
     return df_res
 
 
-@pipe
-def tf_inner(*args, **kwargs):
-    return tran_inner(*args, **kwargs)
-
+tf_inner = add_pipe(tran_inner)
 
 # --------------------------------------------------
 ## Describe
 @curry
 def tran_describe(df):
-    """
-    Describe a dataframe
+    """Describe a dataframe
+
+    Synonym for Pandas df.describe()
 
     Args:
         df (DataFrame): Data to describe
 
     Returns:
-        (Summary)
+        Printed summary
 
     """
     return df.describe()
 
 
-@pipe
-def tf_describe(*args, **kwargs):
-    return tran_describe(*args, **kwargs)
+tf_describe = add_pipe(tran_describe)
